part of model_notifier.mobile;

/// A class that allows the contents of a database to be exported or imported into other files or other persistent information.
class DatabaseExporter {
  DatabaseExporter._();

  /// Export [data] to a file with [fileName].
  ///
  /// No encryption is specifically performed.
  static Future<void> export(String fileName, DynamicMap data) async {
    final json = jsonEncode(data).toAES(fileName.last().toSHA1());
    await File(fileName).writeAsString(json);
  }

  /// Import from a file with [fileName].
  ///
  /// No encryption is specifically performed.
  static Future<DynamicMap> import(String fileName) async {
    final file = File(fileName);
    if (!file.existsSync()) {
      throw Exception("This file [$fileName] is not found.");
    }
    final json = await file.readAsString();
    return jsonDecodeAsMap(json.fromAES(fileName.last().toSHA1()), {});
  }
}
